@@ -5,10 +5,13 @@ x <- seq.int(0, 1, by = 0.01)
 knots <- c(0.3, 0.5, 0.6)
 isMat <- iSpline(x, knots = knots, degree = 2)
 
-par(mar = c(2.5, 2.5, 0.2, 0.1), mgp = c(1.5, 0.5, 0))
+op <- par(mar = c(2.5, 2.5, 0.2, 0.1), mgp = c(1.5, 0.5, 0))
 matplot(x, isMat, type = "l", ylab = "I-spline basis")
 abline(v = knots, lty = 2, col = "gray")
 
+## reset to previous plotting settings
+par(op)
+
 ## the derivative of I-splines is M-spline
 msMat1 <- iSpline(x, knots = knots, degree = 2, derivs = 1)
 msMat2 <- mSpline(x, knots = knots, degree = 2, intercept = TRUE)
