@@ -105,10 +105,10 @@ namespace splines2 {
                     sorted_internal_knots(sorted_internal_knots.n_elem - 1)
                 };
                 if (boundary_knots_.n_elem == 2 &&
-                    (boundary_knots_[0] > min_int_knots ||
-                     boundary_knots_[1] < max_int_knots)) {
+                    (boundary_knots_[0] >= min_int_knots ||
+                     boundary_knots_[1] <= max_int_knots)) {
                     throw std::range_error(
-                        "Internal knots cannot be set outside boundary."
+                        "Internal knots must be set inside boundary."
                         );
                 }
                 // check multiplicity
@@ -260,7 +260,7 @@ namespace splines2 {
         {
             if (has_internal_multiplicity_ || is_extended_knot_sequence_) {
                 throw std::range_error(
-                    "NaturlSpline is only applicable for simple knot sequence."
+                    "Expected a simple knot sequence."
                     );
             }
         }
